Attribute VB_Name = "basOpenWordAndFind"
Option Compare Database
Option Explicit

Function OpenWordAndFind(WordFileName As String, Optional WordFindText) As Boolean
' If the Microsoft Word file specified in WordFileName is not open yet, it will
' be opened.  If a value for WordFindText is specified, it will find the next
' occurance of the value.

' OpenWordAndFind() Version 1.0.0
' Copyright  2009 Extra Mile Data, www.extramiledata.com.
' For questions or issues, please contact support@extramiledata.com.
' Use (at your own risk) and modify freely as long as proper credit is given.
On Error GoTo Err_OpenWordAndFind
   
    Dim strPrompt As String
    Dim objWd As Object
    Dim strAppName As String
    Dim intPos As Integer
    Const wdFindContinue As Integer = 1
    
    ' Get the name of the Word document from the path in WordFileName
    ' by finding the last \ and grabbing all the characters to the right
    ' of that position.
    intPos = InStrRev(WordFileName, "\")
    strAppName = Right(WordFileName, Len(WordFileName) - intPos)
    
    ' If the Word document is already open, get the document.  If it is
    ' not already open, then GetObject will open it.
    Set objWd = GetObject(WordFileName)
    
    ' Make the Word application visible.  It must be visible to do the find.
    objWd.Application.Visible = True
  
    ' If there is text to find, find it.
    If Not IsMissing(WordFindText) Then
        With objWd.Application.Selection.Find
            .Text = WordFindText
            .Forward = True
            .Wrap = wdFindContinue
            .Format = False
            .MatchCase = False
            .MatchWholeWord = False
            .MatchWildcards = False
            .MatchSoundsLike = False
            .MatchAllWordForms = False
            .Execute
            
            ' If the value cannot be found, then message the user, show
            ' the document, and pass back a False.
            If Not .Found Then
                ' So that the user will see the message, activate this
                ' application first.
                AppActivate Application.Name
                ' Show the message.
                strPrompt = "The search term '" & WordFindText & "' cannot be found."
                MsgBox strPrompt, vbInformation + vbOKOnly, "Cannot Find"
                ' Activate the Word window so that it is on top.
                AppActivate strAppName
                ' Pass back a False.
                OpenWordAndFind = False
                GoTo Exit_OpenWordAndFind
            End If
        End With
    End If
    
    ' Activate the Word window so that it is on top.
    AppActivate strAppName
    
    ' Pass back a True.
    OpenWordAndFind = True
    
Exit_OpenWordAndFind:
    On Error Resume Next
    ' Release the Word object.
    Set objWd = Nothing
    Exit Function
    
Err_OpenWordAndFind:
    Select Case Err.Number
    Case 432
        ' Can't find the file.
        strPrompt = "The Word document cannot be found:" _
        & vbCrLf & vbCrLf & WordFileName
        MsgBox strPrompt, vbInformation, "Cannot Find"
    Case Else
        MsgBox Err.Number & " " & Err.Description, , "OpenWordAndFind"
    End Select
    
    ' Pass back a False.
    OpenWordAndFind = False
    Resume Exit_OpenWordAndFind
End Function
